from datetime import datetime, timezone

from flaschengeist.models.user import User

from flaschengeist.database import db
from flaschengeist.models import ModelSerializeMixin, UtcDateTime


class Transaction(db.Model, ModelSerializeMixin):
    __tablename__ = "balance_transaction"
    time: datetime = db.Column(UtcDateTime, nullable=False, default=datetime.now(tz=timezone.utc))
    amount: float = db.Column(db.Numeric(precision=5, scale=2, asdecimal=False), nullable=False)

    _receiver_id = db.Column("receiver_id", db.Integer, db.ForeignKey("user.id"))
    _sender_id = db.Column("sender_id", db.Integer, db.ForeignKey("user.id"))
    _author_id = db.Column("author_id", db.Integer, db.ForeignKey("user.id"), nullable=False)

    sender: User = db.relationship("User", foreign_keys=[_sender_id])
    receiver: User = db.relationship("User", foreign_keys=[_receiver_id])
    author: User = db.relationship("User", foreign_keys=[_author_id])

    _id = db.Column("id", db.Integer, primary_key=True)
